@@ -3,9 +3,9 @@
 # All rights reserved
 __author__ = 'Wu Dong <wudong@eastwu.cn>'
 __title__ = 'pre_request'
-__description__ = 'Deal with request params for Flask'
+__description__ = 'Validate request arguments, Including Cross Field, Cross Struct'
 __url__ = 'https://github.com/Eastwu5788/pre-request'
-__version__ = '2.0.8'
+__version__ = '2.0.10'
 __build__ = 0x000001
 __author_email__ = 'wudong@eastwu.cn'
 __license__ = 'MIT License'
